package Log::ger::Level::Set;

our $DATE = '2018-03-12'; # DATE
our $VERSION = '0.001'; # VERSION

1;
# ABSTRACT: Set log level

__END__

=pod

=encoding UTF-8

=head1 NAME

Log::ger::Level::Set - Set log level

=head1 VERSION

version 0.001

=head1 DESCRIPTION

This distribution contains several modules to set log levels:

=over

=item * L<Log::ger::Level::off>

=item * L<Log::ger::Level::fatal>

=item * L<Log::ger::Level::error>

=item * L<Log::ger::Level::warn>

=item * L<Log::ger::Level::info>

=item * L<Log::ger::Level::debug>

=item * L<Log::ger::Level::trace>

=back

=head1 SEE ALSO

L<Log::ger::Level::FromEnv>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
